summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--git.c12
1 files changed, 6 insertions, 6 deletions
diff --git a/git.c b/git.c
index 63fdda4..ca7208a 100644
--- a/git.c
+++ b/git.c
@@ -93,7 +93,7 @@ int get_info_len(pull_request *pr) {
}
-int create_info_file(pull_request *pr, const char *pr_dir) {
+int create_info_file(pull_request *pr, const char *pr_root) {
int len;
int buf_len;
int j = 0;
@@ -108,14 +108,14 @@ int create_info_file(pull_request *pr, const char *pr_dir) {
return 0;
}
/* Is the PR directory NULL? */
- if (pr_dir == NULL) {
- log(LOG_ERR,"Pull request directory is NULL.");
+ if (pr_root == NULL) {
+ log(LOG_ERR,"Pull request root is NULL.");
return 0;
}
localtime_r(&pr->date, &tm);
- len = strlen(pr_dir) + strlen("/info");
+ len = strlen(pr_root) + strlen("/info");
buf_len = get_info_len(pr);
info = calloc(len+1, sizeof(char));
info_buf = calloc(buf_len+1, sizeof(char));
@@ -138,8 +138,8 @@ int create_info_file(pull_request *pr, const char *pr_dir) {
}
}
- /* Append /info to the PR directory. */
- sprintf(info, "%s/info", pr_dir);
+ /* Append /info to the PR root. */
+ sprintf(info, "%s/info", pr_root);
/* Is there already an info file? */
if (access(info, F_OK) == 0) {